@@ -34,7 +34,6 @@ const { S3ToLambdaProps, S3ToLambda } = require('@aws-solutions-constructs/aws-s
 const stack = new Stack(app, 'test-s3-lambda-stack');
 
 const props: S3ToLambdaProps = {
-    deployLambda: true,
     lambdaFunctionProps: {
         code: lambda.Code.asset(`${__dirname}/lambda`),
         runtime: lambda.Runtime.NODEJS_12_X,
@@ -62,12 +61,10 @@ new S3ToLambda(scope: Construct, id: string, props: S3ToLambdaProps);
 
 | **Name**     | **Type**        | **Description** |
 |:-------------|:----------------|-----------------|
-|deployLambda|`boolean`|Whether to create a new Lambda function or use an existing Lambda function. If set to false, you must provide an existing function for the `existingLambdaObj` property.|
-|existingLambdaObj?|[`lambda.Function`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.Function.html)|An optional, existing Lambda function. This property is required if `deployLambda` is set to false.|
-|lambdaFunctionProps?|[`lambda.FunctionProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.FunctionProps.html)|Optional user-provided props to override the default props for the Lambda function. This property is only required if `deployLambda` is set to true.|
-|deployBucket?|`boolean`|Whether to create a S3 Bucket or use an existing S3 Bucket|
-|existingBucketObj?|[`s3.Bucket`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.Bucket.html)|Existing instance of S3 Bucket object|
-|bucketProps?|[`s3.BucketProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.BucketProps.html)|Optional user provided props to override the default props for S3 Bucket|
+|existingLambdaObj?|[`lambda.Function`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.Function.html)|Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored.|
+|lambdaFunctionProps?|[`lambda.FunctionProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.FunctionProps.html)|User provided props to override the default props for the Lambda function.|
+|existingBucketObj?|[`s3.Bucket`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.Bucket.html)|Existing instance of S3 Bucket object, if this is set then the bucketProps is ignored.|
+|bucketProps?|[`s3.BucketProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.BucketProps.html)|User provided props to override the default props for the S3 Bucket.|
 |s3EventSourceProps?|[`S3EventSourceProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda-event-sources.S3EventSourceProps.html)|Optional user provided props to override the default props for S3EventSourceProps|
 
 ## Pattern Properties
@@ -131,9 +128,7 @@ class S3ToLambda(
         scope: aws_cdk.core.Construct,
         id: str,
         *,
-        deploy_lambda: bool,
         bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
-        deploy_bucket: typing.Optional[bool] = None,
         existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.Bucket] = None,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
         lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
@@ -144,12 +139,10 @@ class S3ToLambda(
         """
         :param scope: - represents the scope for all the resources.
         :param id: - this is a a scope-unique id.
-        :param deploy_lambda: Whether to create a new lambda function or use an existing lambda function. If set to false, you must provide a lambda function object as ``existingObj`` Default: - true
-        :param bucket_props: Optional user provided props to override the default props. If ``deploy`` is set to true only then this property is required Default: - Default props are used
-        :param deploy_bucket: Whether to create a S3 Bucket or use an existing S3 Bucket. If set to false, you must provide S3 Bucket as ``existingBucketObj`` Default: - true
-        :param existing_bucket_obj: Existing instance of S3 Bucket object. If ``deployBucket`` is set to false only then this property is required Default: - None
-        :param existing_lambda_obj: Existing instance of Lambda Function object. If ``deploy`` is set to false only then this property is required Default: - None
-        :param lambda_function_props: Optional user provided props to override the default props. If ``deploy`` is set to true only then this property is required Default: - Default props are used
+        :param bucket_props: User provided props to override the default props for the S3 Bucket. Default: - Default props are used
+        :param existing_bucket_obj: Existing instance of S3 Bucket object, if this is set then the bucketProps is ignored. Default: - None
+        :param existing_lambda_obj: Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored. Default: - None
+        :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default props are used
         :param s3_event_source_props: Optional user provided props to override the default props. Default: - Default props are used
 
         access:
@@ -160,9 +153,7 @@ class S3ToLambda(
         :summary:: Constructs a new instance of the S3ToLambda class.
         """
         props = S3ToLambdaProps(
-            deploy_lambda=deploy_lambda,
             bucket_props=bucket_props,
-            deploy_bucket=deploy_bucket,
             existing_bucket_obj=existing_bucket_obj,
             existing_lambda_obj=existing_lambda_obj,
             lambda_function_props=lambda_function_props,
@@ -186,9 +177,7 @@ class S3ToLambda(
     jsii_type="@aws-solutions-constructs/aws-s3-lambda.S3ToLambdaProps",
     jsii_struct_bases=[],
     name_mapping={
-        "deploy_lambda": "deployLambda",
         "bucket_props": "bucketProps",
-        "deploy_bucket": "deployBucket",
         "existing_bucket_obj": "existingBucketObj",
         "existing_lambda_obj": "existingLambdaObj",
         "lambda_function_props": "lambdaFunctionProps",
@@ -199,9 +188,7 @@ class S3ToLambdaProps:
     def __init__(
         self,
         *,
-        deploy_lambda: bool,
         bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
-        deploy_bucket: typing.Optional[bool] = None,
         existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.Bucket] = None,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
         lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
@@ -210,12 +197,10 @@ class S3ToLambdaProps:
         ] = None,
     ) -> None:
         """
-        :param deploy_lambda: Whether to create a new lambda function or use an existing lambda function. If set to false, you must provide a lambda function object as ``existingObj`` Default: - true
-        :param bucket_props: Optional user provided props to override the default props. If ``deploy`` is set to true only then this property is required Default: - Default props are used
-        :param deploy_bucket: Whether to create a S3 Bucket or use an existing S3 Bucket. If set to false, you must provide S3 Bucket as ``existingBucketObj`` Default: - true
-        :param existing_bucket_obj: Existing instance of S3 Bucket object. If ``deployBucket`` is set to false only then this property is required Default: - None
-        :param existing_lambda_obj: Existing instance of Lambda Function object. If ``deploy`` is set to false only then this property is required Default: - None
-        :param lambda_function_props: Optional user provided props to override the default props. If ``deploy`` is set to true only then this property is required Default: - Default props are used
+        :param bucket_props: User provided props to override the default props for the S3 Bucket. Default: - Default props are used
+        :param existing_bucket_obj: Existing instance of S3 Bucket object, if this is set then the bucketProps is ignored. Default: - None
+        :param existing_lambda_obj: Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored. Default: - None
+        :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default props are used
         :param s3_event_source_props: Optional user provided props to override the default props. Default: - Default props are used
 
         summary:
@@ -231,13 +216,9 @@ class S3ToLambdaProps:
             s3_event_source_props = aws_cdk.aws_lambda_event_sources.S3EventSourceProps(
                 **s3_event_source_props
             )
-        self._values = {
-            "deploy_lambda": deploy_lambda,
-        }
+        self._values = {}
         if bucket_props is not None:
             self._values["bucket_props"] = bucket_props
-        if deploy_bucket is not None:
-            self._values["deploy_bucket"] = deploy_bucket
         if existing_bucket_obj is not None:
             self._values["existing_bucket_obj"] = existing_bucket_obj
         if existing_lambda_obj is not None:
@@ -247,44 +228,18 @@ class S3ToLambdaProps:
         if s3_event_source_props is not None:
             self._values["s3_event_source_props"] = s3_event_source_props
 
-    @builtins.property
-    def deploy_lambda(self) -> bool:
-        """Whether to create a new lambda function or use an existing lambda function.
-
-        If set to false, you must provide a lambda function object as ``existingObj``
-
-        default
-        :default: - true
-        """
-        return self._values.get("deploy_lambda")
-
     @builtins.property
     def bucket_props(self) -> typing.Optional[aws_cdk.aws_s3.BucketProps]:
-        """Optional user provided props to override the default props.
-
-        If ``deploy`` is set to true only then this property is required
+        """User provided props to override the default props for the S3 Bucket.
 
         default
         :default: - Default props are used
         """
         return self._values.get("bucket_props")
 
-    @builtins.property
-    def deploy_bucket(self) -> typing.Optional[bool]:
-        """Whether to create a S3 Bucket or use an existing S3 Bucket.
-
-        If set to false, you must provide S3 Bucket as ``existingBucketObj``
-
-        default
-        :default: - true
-        """
-        return self._values.get("deploy_bucket")
-
     @builtins.property
     def existing_bucket_obj(self) -> typing.Optional[aws_cdk.aws_s3.Bucket]:
-        """Existing instance of S3 Bucket object.
-
-        If ``deployBucket`` is set to false only then this property is required
+        """Existing instance of S3 Bucket object, if this is set then the bucketProps is ignored.
 
         default
         :default: - None
@@ -293,9 +248,7 @@ class S3ToLambdaProps:
 
     @builtins.property
     def existing_lambda_obj(self) -> typing.Optional[aws_cdk.aws_lambda.Function]:
-        """Existing instance of Lambda Function object.
-
-        If ``deploy`` is set to false only then this property is required
+        """Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored.
 
         default
         :default: - None
@@ -306,9 +259,7 @@ class S3ToLambdaProps:
     def lambda_function_props(
         self,
     ) -> typing.Optional[aws_cdk.aws_lambda.FunctionProps]:
-        """Optional user provided props to override the default props.
-
-        If ``deploy`` is set to true only then this property is required
+        """User provided props to override the default props for the Lambda function.
 
         default
         :default: - Default props are used
